@@ -441,7 +441,7 @@
   "`skk-latin-mode' $B$K$*$$$F!"(B`skk-j-mode' $B$KF~$k$?$a$N%3%^%s%I!#(B
 $B:81&?F;X%-!<$NF1;~BG80$r8!=P$7$?>l9g$K(B `skk-j-mode' $B$KF~$k!#(B"
   (interactive "*p")
-  (if (skk-sit-for skk-nicola-latin-interval t)
+  (if (sit-for skk-nicola-latin-interval t)
       ;; then
       (skk-bind-last-command-char
 	  (if (characterp (event-to-character
@@ -522,7 +522,7 @@
       (setq skk-nicola-okuri-flag nil))
     ;;
     (cond
-     ((skk-sit-for skk-nicola-interval t)
+     ((sit-for skk-nicola-interval t)
       ;; No input in the interval.
       (skk-nicola-insert-single this-command arg parg))
      (t
@@ -610,7 +610,7 @@
 	third-event
 	third)
   (cond
-   ((skk-sit-for period1 t)
+   ((sit-for period1 t)
     ;; 3 $B$D$a$NBG80$O@)8B;~4VFb$K$J$+$C$?!#F1;~BG80$H3NDj!#(B(< t1 t2)
     (skk-nicola-insert-double first next arg))
    (t
