@@ -5,10 +5,10 @@
 
 ;; Author: NAKAJIMA Mikio <minakaji@osaka.email.ne.jp>
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
-;; Version: $Id: skk-annotation.el,v 1.230 2011/12/14 22:32:48 skk-cvs Exp $
+;; Version: $Id: skk-annotation.el,v 1.236 2013/01/13 09:45:48 skk-cvs Exp $
 ;; Keywords: japanese, mule, input method
 ;; Created: Oct. 27, 2000.
-;; Last Modified: $Date: 2011/12/14 22:32:48 $
+;; Last Modified: $Date: 2013/01/13 09:45:48 $
 
 ;; This file is part of Daredevil SKK.
 
@@ -81,7 +81,7 @@
 ;;    $B!V$$$<$s(B /$B0JA0(B;previous/$B0MA3(B;still/$B!W(B
 ;;
 ;; $B%f!<%6%"%N%F!<%7%g%s$H%7%9%F%`%"%N%F!<%7%g%s$r6hJL$9$k$3$H$G!"%f!<(B
-;; $B%6%"%N%F!<%7%g%s$@$1$rI=<($7$?$j!"$"$k$$$O$=$N5U$r9T$J$&$3$H$,2DG=(B
+;; $B%6%"%N%F!<%7%g%s$@$1$rI=<($7$?$j!"$"$k$$$O$=$N5U$r9T$&$3$H$,2DG=(B
 ;; $B$G$9!#(B`skk-annotation-function' $B$KI=<($7$?$$%"%N%F!<%7%g%s$r(B
 ;; non-nil $B$HH=Dj$9$k4X?t$r=q$-$^$7$g$&!#$3$s$J46$8$G$9!#(B
 ;;
@@ -105,7 +105,7 @@
 ;;
 ;; $B$7$F2<$5$$!#(B
 ;;
-;; Viper $BBP:v$O$^$@9T$J$C$F$$$^$;$s!#(B~/.viper $B$K<!$N$h$&$K=q$$$F2<$5$$!#(B
+;; Viper $BBP:v$O$^$@9T$C$F$$$^$;$s!#(B~/.viper $B$K<!$N$h$&$K=q$$$F2<$5$$!#(B
 ;; (viper-harness-minor-mode "skk-annotation")
 ;;
 ;; <lookup.el $B$+$i$N%"%N%F!<%7%g%s(B>
@@ -180,7 +180,7 @@
 ;;
 ;;   M-x skk-annotation-update-jisyo-format
 ;;
-;; $B$9$k$3$H$G$3$N:n6H$r9T$J$&$3$H$,$G$-$^$9!#(B
+;; $B$9$k$3$H$G$3$N:n6H$r9T$&$3$H$,$G$-$^$9!#(B
 ;;
 ;; $BC"$7!"4{$K%"%N%F!<%7%g%s$,IU$1$i$l$F$$$k>l9g$O!"$3$N%"%N%F!<%7%g%s(B
 ;; $B<+BN$b8uJd$H6hJL$G$-$:$K(B quote $B$5$l$F$7$^$$$^$9$N$G!"$4Cm0U2<$5$$(B
@@ -276,7 +276,7 @@
 
 (defun skkannot-sit-for (seconds &optional listing-p)
   (condition-case nil
-      (skk-sit-for seconds)
+      (sit-for seconds)
     (quit
      (with-current-buffer skkannot-buffer-origin
        (cond
@@ -425,9 +425,10 @@
 
 ;;;###autoload
 (defun skk-annotation-display-p (test)
+  ;; TEST $B$O(B 'list $BKt$O(B 'minibuf
   (skkannot-clear-msg)
   ;;
-  (cond ((eq skk-show-annotation nil)
+  (cond ((null skk-show-annotation)
 	 nil)
 	((and (listp skk-show-annotation)
 	      (eq (car skk-show-annotation) 'not)
@@ -442,7 +443,7 @@
 ;;;###autoload
 (defun skk-annotation-toggle-display-p ()
   (interactive)
-  (cond ((eq skk-show-annotation nil)
+  (cond ((null skk-show-annotation)
 	 ;; do nothing
 	 nil)
 	((and (listp skk-show-annotation)
@@ -761,13 +762,7 @@ NO-PREVIOUS-ANNOTATION $B$r;XDj(B (\\[Universal-Argument] \\[skk-annotation-ad
 			   (t
 			    (apply #'skkannot-generate-url
 				   "http://%s.org/wiki/%s"
-				   ;; split-string $B$NHs8_49@-$KG[N8(B
-				   (if (eval-when-compile
-					 (and skk-running-gnu-emacs
-					      (<= emacs-major-version 21)))
-				       (cdr (split-string (cdr cache) " "))
-				     (cdr (split-string (cdr cache) " "
-							t))))))))
+				   (cdr (split-string (cdr cache) " " t)))))))
 		 (when url
 		   (setq urls (cons url urls)))))
 	     (unless (equal annotation "")
@@ -891,22 +886,22 @@ NO-PREVIOUS-ANNOTATION $B$r;XDj(B (\\[Universal-Argument] \\[skk-annotation-ad
     ;;
     (condition-case nil
 	(cond ((eq situation 'annotation)
-	       (if (skk-sit-for skk-verbose-wait)
+	       (if (sit-for skk-verbose-wait)
 		   (let ((i 0))
 		     (catch 'loop
 		       (while (< i 20)
 			 (message "%s" skk-annotation-message)
-			 (unless (skk-sit-for skk-verbose-message-interval)
+			 (unless (sit-for skk-verbose-message-interval)
 			   (throw 'loop nil))
 			 (message "%s" skk-annotation-wikipedia-message)
-			 (unless (skk-sit-for skk-verbose-message-interval)
+			 (unless (sit-for skk-verbose-message-interval)
 			   (throw 'loop nil))
 			 (setq i (1+ i))))
 		     (message nil))
 		 nil))
 	      ;;
 	      (t
-	       (when (skk-sit-for skk-verbose-wait)
+	       (when (sit-for skk-verbose-wait)
 		 (message "%s" skk-annotation-wikipedia-message))))
       (quit
        (when (eq skk-henkan-mode 'active)
@@ -965,6 +960,7 @@ NO-PREVIOUS-ANNOTATION $B$r;XDj(B (\\[Universal-Argument] \\[skk-annotation-ad
   "dict $B$NFbMF$r3JG<$9$k%P%C%U%!$N%U%)!<%^%C%H!#(B"
   (format "  *skk dict %s" word))
 
+(declare-function comint-send-string "comint")
 (defun skkannot-py-send-string (string)
   "Evaluate STRING in inferior Python process."
   (require 'comint)
@@ -978,9 +974,10 @@ NO-PREVIOUS-ANNOTATION $B$r;XDj(B (\\[Universal-Argument] \\[skk-annotation-ad
       ;; as to make sure we terminate the multiline instruction.
       (comint-send-string proc "\n"))))
 
+(declare-function compilation-forget-errors "compile")
 (defun skkannot-py-send-command (command)
   "Like `skkannot-py-send-string' but resets `compilation-shell-minor-mode'."
-  (when (or (eval-when-compile (and skk-running-gnu-emacs
+  (when (or (eval-when-compile (and (featurep 'emacs)
 				    (= emacs-major-version 22)))
 	    (python-check-comint-prompt (get-buffer-process
 					 skkannot-py-buffer)))
@@ -1296,10 +1293,7 @@ NO-PREVIOUS-ANNOTATION $B$r;XDj(B (\\[Universal-Argument] \\[skk-annotation-ad
 	   (append '(("sup" . skkannot-wikipedia-clean-sup)
 		     ("sub" . skkannot-wikipedia-clean-sub))
 		   html2text-format-tag-list))
-	  (url-retrieve-func
-	   (if (fboundp 'url-queue-retrieve)
-	       #'url-queue-retrieve
-	     #'url-retrieve))
+	  (url-retrieve-func #'url-retrieve)
 	  buf buffer)
       (if (get-buffer cache-buffer)
 	  (with-current-buffer cache-buffer
