@@ -7,9 +7,9 @@
 
 ;; Author: Masahiko Sato <masahiko@kuis.kyoto-u.ac.jp>
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
-;; Version: $Id: skk-kcode.el,v 1.107 2012/11/26 12:51:12 skk-cvs Exp $
+;; Version: $Id: skk-kcode.el,v 1.109 2013/08/18 02:29:37 skk-cvs Exp $
 ;; Keywords: japanese, mule, input method
-;; Last Modified: $Date: 2012/11/26 12:51:12 $
+;; Last Modified: $Date: 2013/08/18 02:29:37 $
 
 ;; This file is part of Daredevil SKK.
 
@@ -436,10 +436,13 @@ To find a character in `%s', type 7/8 bits JIS code (00nn),\
   "$B%]%$%s%H$K$"$kJ8;z$N6hE@HV9f!"(BJIS $B%3!<%I!"(BEUC $B%3!<%I!"%7%U%H(B JIS $B%3!<%I(B\
 $B5Z$S%f%K%3!<%I$rI=<($9$k!#(B"
   (interactive)
-  (if (eobp)
-      (skk-message "$B%+!<%=%k$,%P%C%U%!$N=*C<$K$"$j$^$9(B"
-		   "Cursor is at the end of the buffer")
-    (skk-display-code (following-char) (point)))
+  (cond ((not skk-display-code-method)
+	 (insert (format "%s" (this-command-keys))))
+	((eobp)
+	 (skk-message "$B%+!<%=%k$,%P%C%U%!$N=*C<$K$"$j$^$9(B"
+		      "Cursor is at the end of the buffer"))
+	(t
+	 (skk-display-code (following-char) (point))))
   t) ; $B%(%3!<$7$?J8;zNs$r%+%l%s%H%P%C%U%!$KA^F~$7$J$$$h$&$K!#(B
 
 (defun skk-display-code (char p)
@@ -552,8 +555,8 @@ To find a character in `%s', type 7/8 bits JIS code (00nn),\
      ((and window-system
 	   skk-show-tooltip
 	   (not (eq (symbol-function 'skk-tooltip-show-at-point) 'ignore)))
-      (funcall skk-tooltip-function
-	       (replace-regexp-in-string ", " "\n\t" mesg)))
+      (skk-tooltip-show-at-point (replace-regexp-in-string ", " "\n\t" mesg)
+				 'annotation))
      (skk-show-candidates-always-pop-to-buffer
       (skk-annotation-show (replace-regexp-in-string ", " "\n\t" mesg)))
      (t
