@@ -6,9 +6,9 @@
 
 ;; Author: Masahiko Sato <masahiko@kuis.kyoto-u.ac.jp>
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
-;; Version: $Id: skk-num.el,v 1.48 2011/06/03 23:35:25 skk-cvs Exp $
+;; Version: $Id: skk-num.el,v 1.52 2013/01/17 13:50:39 skk-cvs Exp $
 ;; Keywords: japanese, mule, input method
-;; Last Modified: $Date: 2011/06/03 23:35:25 $
+;; Last Modified: $Date: 2013/01/17 13:50:39 $
 
 ;; This file is part of Daredevil SKK.
 
@@ -209,15 +209,16 @@
 
 ;;;###autoload
 (defun skk-num-exp (num type)
-  "ascii $B?t;z(B (string) $B$N(B NUM $B$r(B TYPE $B$K=>$$JQ49$7!"JQ498e$NJ8;zNs$rJV$9!#(B
+  "ascii $B?t;z(B (string) $B$N(B NUM $B$r(B TYPE $B$K=>$C$FJQ49$7$?J8;zNs$rJV$9!#(B
 TYPE $B$O2<5-$NDL$j!#(B
 0 -> $BL5JQ49(B
 1 -> $BA43Q?t;z$XJQ49(B
-2 -> $B4A?t;z$XJQ49(B ($B0L<h$j$J$7(B)
-3 -> $B4A?t;z$XJQ49(B ($B0L<h$j$r$9$k(B)
+2 -> $B4A?t;z(B ($B0L<h$j$"$j(B) $B$XJQ49!#Nc(B;1024 -> $B0l!;Fs;M(B
+3 -> $B4A?t;z(B ($B0L<h$j$J$7(B) $B$XJQ49!#Nc(B;1024 -> $B@iFs==;M(B
 4 -> $B$=$N?t;z$=$N$b$N$r%-!<$K$7$F<-=q$r:F8!:w(B
-5 -> $B4A?t;z(B ($B<j7A$J$I$G;HMQ$9$kJ8;z$r;HMQ(B) $B$XJQ49(B ($B0L<h$j$r$9$k(B)
-9 -> $B>-4}$G;HMQ$9$k?t;z(B (\"$B#3;M(B\" $B$J$I(B) $B$KJQ49(B"
+5 -> $B4A?t;z(B ($B<j7A$J$I$G;HMQ$9$kJ8;z$r;HMQ(B) $B$XJQ49(B
+8 -> $B7e6h@Z$j$XJQ49(B (1,234,567)
+9 -> $B>-4}$G;HMQ$9$k?t;z(B (\"$B#3;M(B\" $B$J$I(B) $B$XJQ49(B"
   (save-match-data
     (let ((fun (cdr (assq type skk-num-type-alist))))
       (when fun
@@ -234,8 +235,8 @@ TYPE $B$O2<5-$NDL$j!#(B
       candidate)))
 
 (defun skk-num-type2-kanji (num)
-  "ascii $B?t;z(B NUM $B$r4A?t;z$NJ8;zNs$KJQ49$7!"JQ498e$NJ8;zNs$rJV$9!#(B
-$BNc$($P!"(B\"45\" $B$r(B \"$B;M8^(B\" $B$KJQ49$9$k!#(B"
+  "ascii $B?t;z(B NUM $B$r4A?t;z$NJ8;zNs(B ($B0L<h$j$"$j(B) $B$KJQ49$7!"JQ498e$NJ8;zNs$rJV$9!#(B
+$BNc$($P!"(B\"1024\" $B$r(B \"$B0l!;Fs;M(B\" $B$KJQ49$9$k!#(B"
   (save-match-data
     (when (skk-num-int-p num)
       (let ((candidate
@@ -248,16 +249,16 @@ TYPE $B$O2<5-$NDL$j!#(B
 	  candidate)))))
 
 (defun skk-num-type3-kanji (num)
-  "ascii $B?t;z(B NUM $B$r4A?t;z$NJ8;zNs$KJQ49$7(B ($B0L<h$j$r$9$k(B)$B!"JQ498e$NJ8;zNs$r(B
-$BJV$9!#Nc$($P(B \"1021\" $B$r(B \"$B@iFs==0l(B\" $B$KJQ49$9$k!#(B"
+  "ascii $B?t;z(B NUM $B$r4A?t;z$NJ8;zNs(B ($B0L<h$j$J$7(B) $B$KJQ49$7!"JQ498e$NJ8;zNs$rJV$9!#(B
+$BNc$($P(B \"1024\" $B$r(B \"$B@iFs==;M(B\" $B$KJQ49$9$k!#(B"
   (save-match-data
     (when (skk-num-int-p num)
       ;; $B>.?tE@$r4^$^$J$$?t(B
       (skk-num-to-kanji num 'type3))))
 
 (defun skk-num-type5-kanji (num)
-  "ascii $B?t;z(B NUM $B$r4A?t;z$NJ8;zNs$KJQ49$7(B ($B0L<h$j$r$9$k(B)$B!"JQ498e$NJ8;zNs$r(B
-$BJV$9!#Nc$($P(B \"1021\" $B$r(B \"$B0motFu=&0m(B\" $B$KJQ49$9$k!#(B"
+  "ascii $B?t;z(B NUM $B$r4A?t;z$NJ8;zNs$KJQ49$7!"JQ498e$NJ8;zNs$rJV$9!#(B
+$BNc$($P(B \"1021\" $B$r(B \"$B0motFu=&0m(B\" $B$KJQ49$9$k!#(B"
   (save-match-data
     (when (skk-num-int-p num)
       ;; $B>.?tE@$r4^$^$J$$?t(B
@@ -340,6 +341,37 @@ TYPE $B$O2<5-$NDL$j!#(B
     (or v
 	(skk-num-get-suuji ?0 alist))))
 
+(defun add-number-grouping (number &optional separator places)
+  ;; http://www.emacswiki.org/cgi-bin/wiki/AddCommasToNumbers
+  ;; and $B6LLn7r0l(B <suzu@a7m3.jp>
+  "Add commas to NUMBER and return it as a string.
+    Optional SEPARATOR is the string to use to separate groups.
+    It defaults to a comma.
+    PLACES is the number of places of a group.
+    It defaults to three."
+  (let ((num (number-to-string number))
+	(op (or separator
+		","))
+        (pl (or (if (< places 1) 3 places)
+		3))) 
+    (while (string-match (concat "\\(.*[0-9]\\)\\([0-9]\\{"
+				 (number-to-string pl)
+				 "\\}.*\\)")
+			 num)
+      (setq num (concat (match-string 1 num)
+			op
+			(match-string 2 num))))
+    num))
+
+(defun skk-num-grouping (num)
+  "ascii $B?t;z$N(B NUM $B$r7e6h@Z$j$XJQ49$7!"JQ498e$NJ8;zNs$rJV$9!#(B
+$BNc$($P(B \"1234567\" $B$r(B \"1,234,567\" $B$XJQ49$9$k!#(B
+$B6h@Z$k5-9f$O(B `skk-num-grouping-separator' $B$G!"6h@Z$k7e?t$O(B `skk-num-grouping-places' $B$G;XDj$9$k!#(B"
+  (add-number-grouping (string-to-number num)	  ; number
+		       skk-num-grouping-separator ; `,'
+		       skk-num-grouping-places	  ; 3
+		       ))
+
 (defun skk-num-shogi (num)
   "ascii $B?t;z$N(B NUM $B$r>-4}$G;HMQ$5$l$k?t;zI=5-$KJQ49$9$k!#(B
 $BNc$($P(B \"34\" $B$r(B \"$B#3;M(B\" $B$KJQ49$9$k!#(B"
@@ -368,7 +400,7 @@ TYPE $B$O2<5-$NDL$j!#(B
 	    skk-henkan-okurigana skk-okuri-char skk-use-numeric-conversion)
 	(while skk-current-search-prog-list
 	  (setq result (skk-nunion result (skk-search))))))
-    ;; $B$3$3$G(B temp-buffer $B$r=P$FJQ49$r9T$J$C$F$$$k%+%l%s%H%P%C%U%!$KLa$k(B
+    ;; $B$3$3$G(B temp-buffer $B$r=P$FJQ49$r9T$C$F$$$k%+%l%s%H%P%C%U%!$KLa$k(B
     ;; ($B%P%C%U%!%m!<%+%kCM$G$"$k(B skk-henkan-list $B$rA`:n$7$?$$$?$a(B)$B!#(B
     (cond
      ((not result)
@@ -427,7 +459,7 @@ TYPE $B$O2<5-$NDL$j!#(B
 			 tail3 (substring e3 (match-end 0)))))))
 	(when (and type2and3 type2 type3
 		   ;; $B?tCMJQ49$r<($9J8;zNs(B "#[23]" $B$NA08e$NJ8;zNs$bF10l$N$H(B
-		   ;; $B$-$N$_(B uniq $B$r9T$J$&!#(B
+		   ;; $B$-$N$_(B uniq $B$r9T$&!#(B
 		   (string= head2 head3) (string= tail2 tail3))
 	  (if (> index2 index3)
 	      ;; "#3" $B$NJ}$,A0$K$"$k!#(B
@@ -447,14 +479,14 @@ TYPE $B$O2<5-$NDL$j!#(B
 ;;;###autoload
 (defun skk-num-henkan-key ()
   "$BE,@Z$JJQ49%-!<$rJV$9!#(B
-type4 $B$N?tCM:FJQ49$,9T$J$o$l$?$H$-$O!"?tCM<+?H$rJV$7!"$=$l0J30$N?tCMJQ49(B
+type4 $B$N?tCM:FJQ49$,9T$o$l$?$H$-$O!"?tCM<+?H$rJV$7!"$=$l0J30$N?tCMJQ49(B
 $B$G$O!"(B`skk-henkan-key' $B$N?tCM$r(B \"#\" $B$GCV$-49$($?%-!<$rJV$9!#(B"
   (or skk-num-recompute-key
       (skk-num-compute-henkan-key skk-henkan-key)))
 
 ;;;###autoload
 (defun skk-num-update-jisyo (noconvword word &optional purge)
-  "$B?t;z<+?H$r8+=P$78l$H$7$F<-=q$N%"%C%W%G!<%H$r9T$J$&!#(B"
+  "$B?t;z<+?H$r8+=P$78l$H$7$F<-=q$r%"%C%W%G!<%H$9$k!#(B"
   (when (and skk-num-recompute-key
 	     (save-match-data (string-match "#4" noconvword)))
     (with-current-buffer (skk-get-jisyo-buffer skk-jisyo 'nomsg)
