@@ -7,9 +7,9 @@
 
 ;; Author: Masahiko Sato <masahiko@kuis.kyoto-u.ac.jp>
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
-;; Version: $Id: skk-tut.el,v 1.90 2012/08/28 12:14:21 skk-cvs Exp $
+;; Version: $Id: skk-tut.el,v 1.92 2013/03/20 06:53:31 skk-cvs Exp $
 ;; Keywords: japanese, mule, input method
-;; Last Modified: $Date: 2012/08/28 12:14:21 $
+;; Last Modified: $Date: 2013/03/20 06:53:31 $
 
 ;; This file is part of Daredevil SKK.
 
@@ -395,18 +395,18 @@
   ;; skktut-japanese-tut $B$,(B non-nil $B$@$C$?$i(B JAPANESE $B$r(B nil $B$G$"$l$P(B ENGLISH
   ;; $B$r%(%3!<%(%j%"$KI=<($9$k!#(B
   ;; ARG $B$O(B message $B4X?t$NBh#20z?t0J9_$N0z?t$H$7$FEO$5$l$k!#(B
-  (append (list 'message (list 'if 'skktut-japanese-tut japanese english))
+  (append `(message (if skktut-japanese-tut ,japanese ,english))
 	  arg))
 
 (defmacro skktut-error (japanese english &rest arg)
   ;; skktut-japanese-tut $B$,(B non-nil $B$@$C$?$i(B JAPANESE $B$r(B nil $B$G$"$l$P(B ENGLISH
   ;; $B$r%(%3!<%(%j%"$KI=<($7!"%(%i!<$rH/@8$5$;$k!#(B
   ;; ARG $B$O(B error $B4X?t$NBh#20z?t0J9_$N0z?t$H$7$FEO$5$l$k!#(B
-  (append (list 'error (list 'if 'skktut-japanese-tut japanese english))
+  (append `(error (if skktut-japanese-tut ,japanese ,english))
 	  arg))
 
 (defmacro skktut-yes-or-no-p (japanese english)
-  (list 'yes-or-no-p (list 'if 'skktut-japanese-tut japanese english)))
+ `(yes-or-no-p (if skktut-japanese-tut ,japanese ,english)))
 
 ;; advices.
 (defadvice skk-create-file (around skktut-ad disable))
@@ -546,7 +546,7 @@ You can select English version by \\[universal-argument] \\[skk-tutorial]."
   (interactive "P")
   (when (or now
 	    (skktut-yes-or-no-p
-	     "$BK\Ev$K%A%e!<%H%j%"%k$r$d$a$^$9$+(B? "
+	     "$BK\Ev$K%A%e!<%H%j%"%k$r$d$a$^$9$+!)(B "
 	     "Really quit tutorial? "))
     (let ((inhibit-quit t))
       (delete-other-windows)
